import { world, system, ItemStack } from "@minecraft/server";

const tools = [
    {
        id: "nk:mysterium_pickaxe"
    },
    {
        id: "nk:mysterium_sword"
    },
    {
        id: "nk:mysterium_axe"
    },
    {
        id: "nk:mysterium_shovel"
    },
    {
        id: "nk:mysterium_hoe"
    }
]

const end_stone = new ItemStack('minecraft:end_stone', 1)

world.beforeEvents.playerBreakBlock.subscribe((data) => {
    const block = data.block;
    const tool = data.itemStack?.typeId;
    if (block.typeId === 'nk:deepslate_mysterium_ore') {
        if (tool) {
            if (tool === 'minecraft:netherite_pickaxe' || tool === 'nk:mysterium_pickaxe') {
                if (tool === 'minecraft:netherite_pickaxe') {
                    const silk_touch = data.itemStack.getComponent('enchantable').hasEnchantment('silk_touch')
                    if (!silk_touch) {
                        data.cancel = true;
                        system.run(() => {
                            world.getDimension(block.dimension.id).setBlockType(block.location, 'air');
                            world.getDimension(block.dimension.id).playSound('dig.stone', block.location);
                            world.getDimension(block.dimension.id).spawnItem(end_stone, block.location)
                        })
                    }
                }
            }
            else {
                data.cancel = true;
                system.run(() => {
                    world.getDimension(block.dimension.id).setBlockType(block.location, 'air');
                    world.getDimension(block.dimension.id).playSound('dig.stone', block.location)
                    world.getDimension(block.dimension.id).spawnItem(end_stone, block.location)
                })
            }
        }
    }

    const player = data.player;
    const item = data.itemStack;
    if (item && item.typeId.startsWith('nk:')) {
        tools.forEach(tool => {
            if (item.typeId === tool.id) {
                const slot = player.selectedSlotIndex;
                const inventory = player.getComponent('inventory').container;
                const enchants = item?.getComponent('minecraft:enchantable')?.getEnchantments()
                const unbreaking = enchants?.map(e => { if (e.type.id === 'unbreaking') return e })[0];
                const itemDurability = item.getComponent('durability');
                const itemMaxDurability = itemDurability.maxDurability;
                const itemDamage = itemDurability.damage;

                system.run(() => {
                    if (itemMaxDurability - itemDamage === 0) {
                        inventory.setItem(slot)
                        player.playSound('random.break')
                    }
                    else if (unbreaking) {
                        if (unbreaking.level === 1) {
                            const random1 = Math.round(Math.random(1 / (1 + 1)) * 1)
                            itemDurability.damage += random1;
                            inventory.setItem(slot, item);
                        }
                        if (unbreaking.level === 2) {
                            const random2 = Math.round(Math.random(1 / (2 + 1)) * 1)
                            itemDurability.damage += random2;
                            inventory.setItem(slot, item);
                        }
                        if (unbreaking.level === 3) {
                            const random3 = Math.round(Math.random(1 / (4 + 1)) * 1)
                            itemDurability.damage += random3;
                            inventory.setItem(slot, item);
                        }
                    } else {
                        itemDurability.damage++;
                        inventory.setItem(slot, item);
                    }
                })
            }
        })
    }
})

world.beforeEvents.itemUseOn.subscribe((data) => {
    const { block, blockFace, faceLocation, isFirstEvent, itemStack, source } = data;
    if (itemStack.typeId === 'nk:mysterium_shovel') {
        try {
            system.run(() => {
                if (block.typeId === 'minecraft:campfire' || block.typeId === 'minecraft:soul_campfire') {
                    const blockPosition = block.location;
                    const perm = block.permutation.withState("extinguished", true)
                    world.getDimension(source.dimension.id).setBlockPermutation(blockPosition, perm);
                }
                if (block.typeId === 'minecraft:dirt') {
                    const blockPosition = block.location;
                    world.getDimension(source.dimension.id).setBlockType(blockPosition, 'minecraft:grass_path')
                }
            })
        } catch (error) {
            console.error(error);
        }
    }
})